#
# spec file for package python-qt5
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-qt5
Version:        5.13.1
Release:        lp153.1.36
Summary:        Python bindings for Qt 5
License:        SUSE-GPL-2.0-with-FLOSS-exception OR GPL-3.0-only OR NonFree
Group:          Development/Libraries/Python
URL:            https://www.riverbankcomputing.com/software/pyqt
Source:         https://www.riverbankcomputing.com/static/Downloads/PyQt5/%{version}/PyQt5_gpl-%{version}.tar.gz
Source99:       %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE - disable-rpaths.diff - Disable RPATH when building PyQt5.
Patch1:         disable-rpaths.diff
# PATCH-FIX-UPSTREAM
Patch2:         update-timeline.patch
# PATCH-FIX-UPSTREAM - add-qkeysequenceedit-to-uic.patch
Patch3:         add-qkeysequenceedit-to-uic.patch
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module sip-devel >= 4.19.19}
BuildRequires:  dbus-1-devel
BuildRequires:  dbus-1-python-devel
BuildRequires:  dbus-1-python3-devel
BuildRequires:  fdupes
BuildRequires:  gdb
BuildRequires:  libqt5-qtbase-devel
BuildRequires:  pkgconfig
BuildRequires:  python-enum34
BuildRequires:  python-rpm-macros
BuildRequires:  pkgconfig(Qt5Bluetooth)
BuildRequires:  pkgconfig(Qt5Designer)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Location)
BuildRequires:  pkgconfig(Qt5Multimedia)
BuildRequires:  pkgconfig(Qt5MultimediaWidgets)
BuildRequires:  pkgconfig(Qt5Nfc)
BuildRequires:  pkgconfig(Qt5Positioning)
BuildRequires:  pkgconfig(Qt5Qml)
BuildRequires:  pkgconfig(Qt5Quick)
BuildRequires:  pkgconfig(Qt5QuickWidgets)
BuildRequires:  pkgconfig(Qt5SerialPort)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5UiTools)
BuildRequires:  pkgconfig(Qt5WebChannel)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5X11Extras)
BuildRequires:  pkgconfig(Qt5XmlPatterns)
Requires:       %{name}-utils
Requires:       python-sip(api) = %{python_sip_api_ver}
%requires_ge    libqt5-x11
%requires_ge    python-dbus-python
Provides:       python-PyQt5 = %{version}
%ifpython2
Requires:       python-enum34
%endif
# Do not build WebKit support from SLE15
%if 0%{?is_opensuse} || 0%{?suse_version} < 1500
BuildRequires:  pkgconfig(Qt5WebKit)
BuildRequires:  pkgconfig(Qt5WebKitWidgets)
%endif
# Do not build WebEngine support from SLE15
%if 0%{?is_opensuse} && 0%{?suse_version} >= 1320
%ifnarch ppc ppc64 ppc64le s390 s390x riscv64
BuildRequires:  pkgconfig(Qt5WebEngine)
BuildRequires:  pkgconfig(Qt5WebEngineCore)
BuildRequires:  pkgconfig(Qt5WebEngineWidgets)
%endif
%endif
# Do not build Qt5NetworkAuth support in SLE
%if 0%{?is_opensuse}
BuildRequires:  pkgconfig(Qt5NetworkAuth)
%endif
%ifpython2
%requires_ge    dbus-1-python
%endif
%ifpython3
%requires_ge    dbus-1-python3
%endif
%python_subpackages

%description
PyQt is a set of Python bindings for Trolltech's Qt application
framework. The qt4 and qt5 bindings can be co-installed.

%package devel
Summary:        PyQt - devel part of python bindings for Qt 5
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}
Requires:       libqt5-qtbase-devel
Requires:       python-devel
Requires:       python-qt5-utils
Requires:       python-sip-devel >= 4.19.11
Requires:       pkgconfig(Qt5Bluetooth)
Requires:       pkgconfig(Qt5Designer)
Requires:       pkgconfig(Qt5Help)
Requires:       pkgconfig(Qt5Location)
Requires:       pkgconfig(Qt5Multimedia)
Requires:       pkgconfig(Qt5MultimediaWidgets)
Requires:       pkgconfig(Qt5Nfc)
Requires:       pkgconfig(Qt5Positioning)
Requires:       pkgconfig(Qt5Qml)
Requires:       pkgconfig(Qt5Quick)
Requires:       pkgconfig(Qt5QuickWidgets)
Requires:       pkgconfig(Qt5SerialPort)
Requires:       pkgconfig(Qt5Svg)
Requires:       pkgconfig(Qt5UiTools)
Requires:       pkgconfig(Qt5WebChannel)
Requires:       pkgconfig(Qt5WebSockets)
Requires:       pkgconfig(Qt5X11Extras)
Requires:       pkgconfig(Qt5XmlPatterns)
Requires(post): update-alternatives
Requires(postun): update-alternatives
Recommends:     python-qscintilla-qt5
Provides:       python-PyQt5-devel = %{version}
%ifpython2
Requires:       python-enum34
%endif
# Do not build WebKit support from SLE15
%if 0%{?is_opensuse} || 0%{?suse_version} < 1500
Requires:       pkgconfig(Qt5WebKit)
Requires:       pkgconfig(Qt5WebKitWidgets)
%endif
# Do not build WebEngine support from SLE15
%if 0%{?is_opensuse} && 0%{?suse_version} >= 1320
%ifnarch ppc ppc64 ppc64le s390 s390x riscv64
Requires:       pkgconfig(Qt5WebEngine)
Requires:       pkgconfig(Qt5WebEngineCore)
Requires:       pkgconfig(Qt5WebEngineWidgets)
%endif
%endif
%ifpython2
Requires:       dbus-1-python-devel
%endif
%ifpython3
Requires:       dbus-1-python3-devel
%endif

%description devel
PyQt is a set of Python bindings for Trolltech's Qt application
framework. The qt4 and qt5 bindings can be co-installed.

This package contains all the developer tools you need to create your
own PyQt applications.

%package -n %{name}-utils
Summary:        Common files for PyQt5 for python2 and python3
Group:          Development/Libraries/Python
Provides:       %{python_module PyQt5-utils = %{version}}
Provides:       %{python_module qt5-utils = %{version}}

%description -n %{name}-utils
PyQt is a set of Python bindings for Trolltech's Qt application
framework. The qt4 and qt5 bindings can be co-installed.

This package contains common files shared between python2 and python3
versions of PyQt5.

%package -n %{name}-doc
Summary:        Documentation for %{name}
Group:          Documentation/Other
Provides:       %{python_module PyQt5-doc = %{version}}
Provides:       %{python_module qt5-doc = %{version}}

%description -n %{name}-doc
PyQt is a set of Python bindings for Trolltech's Qt application
framework. The qt4 and qt5 bindings can be co-installed.

This package contains documentation and examples for PyQt5.

%prep
%autosetup -p1 -n PyQt5_gpl-%{version}

# Fix wrong-script-interpreter
find examples -name "*.py" -exec sed -i "s|^#!%{_bindir}/env python$|#!%__python3|" {} \;

%build
export CXXFLAGS="%{optflags}"
export CFLAGS="%{optflags}"

%{python_expand mkdir build_%{$python_bin_suffix}

pushd build_%{$python_bin_suffix}

ln -s ../config-tests .
$python ../configure.py --verbose  \
                        --confirm-license \
                        --assume-shared \
                        --debug \
                        --qmake=%{_libqt5_qmake} \
                        --sip=%{_bindir}/sip-%{$python_bin_suffix} \
                        --qsci-api \
                        --qsci-api-destdir=%{_libqt5_datadir}/qsci \
                        QMAKE_CFLAGS+="${CFLAGS} ${CPPFLAGS}" \
                        QMAKE_CXXFLAGS+="${CXXFLAGS} ${CPPFLAGS}" \

make %{?_smp_mflags}

popd

}

%install
mkdir -p %{buildroot}%{_sysconfdir}/alternatives
%{python_expand pushd build_%{$python_bin_suffix}

%make_install INSTALL_ROOT=%{buildroot}

# Point to the correct location for the documentation files
cp ../README ./
sed -i 's/The "doc" directory/The "doc" directory of package %{$python_prefix}-qt5-devel/' README

popd

# Prepare for update-alternatives usage
for p in pyuic5 pylupdate5 pyrcc5 ; do
    mv %{buildroot}%{_bindir}/$p %{buildroot}%{_bindir}/$p-%{$python_bin_suffix}
done

mv %{buildroot}%{_libqt5_plugindir}/designer/libpyqt5.so %{buildroot}%{_libqt5_plugindir}/designer/libpy%{$python_bin_suffix}qt5.so
mv %{buildroot}%{_libqt5_plugindir}/PyQt5/libpyqt5qmlplugin.so %{buildroot}%{_libqt5_plugindir}/PyQt5/libpy%{$python_bin_suffix}qt5qmlplugin.so
mv -T %{buildroot}%{_datadir}/qt5/qsci/api/python %{buildroot}%{_datadir}/qt5/qsci/api/python_%{$python_bin_suffix}
}

for p in pyuic5 pylupdate5 pyrcc5 ; do
    %prepare_alternative $p
done

mkdir -p %{buildroot}%{_docdir}/%{name}
cp -r examples %{buildroot}%{_docdir}/%{name}/
%fdupes %{buildroot}%{_docdir}/%{name}/

%post devel
%{python_install_alternative pyuic5} \
   --slave %{_bindir}/pylupdate5 pylupdate5 %{_bindir}/pylupdate5-%{python_bin_suffix} \
   --slave %{_bindir}/pyrcc5 pyrcc5 %{_bindir}/pyrcc5-%{python_bin_suffix}

%postun devel
%python_uninstall_alternative pyuic5

%files %{python_files}
%license LICENSE
%doc build_%{python_bin_suffix}/README
%doc NEWS ChangeLog
%{python_sitearch}/PyQt5/
%{python_sitearch}/PyQt5-%{version}.dist-info/
%{python_sitelib}/dbus/mainloop/pyqt5.so
%dir %{_libqt5_plugindir}/PyQt5/
%{_libqt5_plugindir}/PyQt5/libpy%{python_bin_suffix}qt5qmlplugin.so
%exclude %{_docdir}/%{name}/examples/

%files %{python_files devel}
%python_alternative %{_bindir}/pyuic5
%python_alternative %{_bindir}/pylupdate5
%python_alternative %{_bindir}/pyrcc5
%dir %{_libqt5_plugindir}/designer/
%{_libqt5_plugindir}/designer/libpy%{python_bin_suffix}qt5.so
%dir %{_datadir}/qt5/qsci/
%dir %{_datadir}/qt5/qsci/api/
%dir %{_datadir}/qt5/qsci/api/python_%{python_bin_suffix}/
%{_datadir}/qt5/qsci/api/python_%{python_bin_suffix}/PyQt5.api

%files -n %{name}-utils
%{_datadir}/sip/PyQt5/

%files -n %{name}-doc
%license LICENSE
%dir %{_docdir}/%{name}
%{_docdir}/%{name}/examples/

%changelog
* Thu Sep 26 2019 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints file for ppc64/ppc64le to avoid build failure
  on power8-06 that ran out of disk space
* Fri Sep 20 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.13.1. Check the ChangeLog file for the list of changes
* Fri Sep 13 2019 Michel Normand <normand@linux.vnet.ibm.com>
- Add %%dir plugindir/designer for %%{python_files devel} in spec
  to avoid build error for PowerPC.
* Wed Sep 11 2019 Hans-Peter Jansen <hpj@urpla.net>
- Add patch to support QKeySequenceEdit widgets in pyuic:
  add-qkeysequenceedit-to-uic.patch
* Fri Jul 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.13.0
  * Code updated to support Qt 5.13
  * Fixed the conversion of the result of
  QNetworkCacheMetaData.attributes()
- Drop reproducible.patch, merged upstream.
* Thu Jun  6 2019 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to make package build reproducible (boo#1041090)
* Mon Jun  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.12.2
  * Fixed QIcon(QIconEngine) to reflect that the engine is explicitly
  shared between every copy of the icon.
  * Eliminated a warning message from QObject::connect()
  * Increased the number of QQuickItem types that can be registered
    from 30 to 60.
  * Fixed the QPolygon ctors
  * Fixed pyuic's handling of 'sizePolicy' properties.
  * Fixed pylupdate to handle empty strings at the end of a line so
    that the line number remains correct.
* Thu Apr 18 2019 Jan Engelhardt <jengelh@inai.de>
- Trim name repetition from summary.
* Wed Apr 17 2019 Todd R <toddrme2178@gmail.com>
- Package .dist-info directory.  The bugs with it have been fixed
  and some packages require it in order to properly detect that
  pyqt5 is installed.
* Sat Apr  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.12.1
  Fixed QIcon(QIconEngine) to reflect that the engine is explicitly
  shared between every copy of the icon.
- Prepare update-timeline.patch for Qt 5.13.0
* Mon Feb 11 2019 Adrian Schröter <adrian@suse.de>
- update to final 5.12 version
  * Support for Qt 5.12
  * Details at https://www.riverbankcomputing.com/static/Downloads/PyQt5/ChangeLog
- fix-sip-detection.patch is obsolete
* Thu Jan 10 2019 Adrian Schröter <adrian@suse.de>
- update to 5.12 development snapshot
* Wed Nov 14 2018 Antonio Larrosa <alarrosa@suse.com>
- Do not build Qt5NetworkAuth support in SLE, which doesn't have the
  libqt5-qtnetworkauth package
* Thu Nov  8 2018 Todd R <toddrme2178@gmail.com>
- python-enum34 is also required at runtime.
* Mon Oct 22 2018 Christophe Giboudeaux <christophe@krop.fr>
- Make sure python-enum34 is installed when building packages
  depending on python-qt5.
* Sun Oct 21 2018 Christophe Giboudeaux <christophe@krop.fr>
- Add fix-sip-detection.patch. Picked from the Fedora package
* Mon Sep 17 2018 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.11.3
  * Fixed a build problem with Python v2.
  * Removed the checks for PyQt5.sip
  * Fix issues with out of source builds
* Wed Aug  8 2018 schwab@suse.de
- No qtwebengine for riscv64 yet
* Mon Jul  2 2018 christophe@krop.fr
- Update to 5.11.2:
  * Added support for Qt v5.11.0 and v5.11.1.
  * Added support for Python v3.7.
  * Enum members are also visible as attributes of the enum in order to emulate
    the behaviour of Python enums.
  * The connect() method of a bound signal now returns a QMetaObject.Connection
    object that can be passed to the disconnect() method.
  * Added the signatures attribute to unbound signals.
  * Added QtCore.Q_ENUM() and QtCore.Q_FLAG().
  * Python enums can now be used with Q_ENUM() etc.
  * Added the missing QGuiApplication.inputMethod() method.
  * Added the missing QGuiApplication.styleHints() method.
  * Added the missing QSqlQuery.exec() overload for Python v3.
  * Added glReadPixels().
- Drop remove-qtest-waitforevents.patch. Fixed upstream.
- Drop qt_quick_crash_fix.patch. Fixed upstream
* Mon Jun 11 2018 fabian@ritter-vogt.de
- Amend patch to mention even more Qt versions:
  * update-timeline.patch
* Tue May 15 2018 adrian@suse.de
- fix URL
- fix crash in Qt Quick when used with Cura (from upstream)
  (regression in 5.10.1, qt_quick_crash_fix.patch)
* Thu May  3 2018 fabian@ritter-vogt.de
- Add patch to remove use of internal Qt function:
  * remove-qtest-waitforevents.patch
* Fri Apr 27 2018 fabian@ritter-vogt.de
- Add patch to support Qt 5.9.4, 5.9.5 and Qt 5.11.0:
  * update-timeline.patch
- Refresh patch to work with -p1:
  * disable-rpaths.diff
* Tue Apr 17 2018 lbeltrame@kde.org
- Remove source URL to workaround SourceForge's unreliability
* Tue Apr 17 2018 termim@gmail.com
- Update to version v5.10.1
  * Added support for Qt v5.10.1.
  * Added the missing qmlClearTypeRegistrations() to the QtQml module.
  * Added the --disabled-feature option to configure.py.
* Fri Jan 26 2018 aloisio@gmx.com
- Update to version v5.10
  * Added support for Qt v5.10.0.
  * Added the QtNetworkAuth module.
  version v5.9.2
  * Added support for Qt v5.9.3.
  * Added the QtAndroidExtras module.
  version v5.9.1
  * Added support for Qt v5.9.2.
  * Added the --allow-sip-warnings option to configure.py.
  * Removed the unimplemented -name option to pyrcc5.
  * SIP v4.19.4 is required.
- Dropped configure_py_Fix_handling_of_disabled_features.patch
  (merged upstream)
* Wed Oct 25 2017 stefan.bruens@rwth-aachen.de
- add configure_py_Fix_handling_of_disabled_features.patch
  configure.py is broken if features are disabled, which e.g. happens
  when building using GLEs Qt5 builds. Taken from upstream
  developement snapshot.
* Fri Sep  1 2017 mlin@suse.com
- Disable WebKit and WebEngine on SLE15.
* Tue Aug 29 2017 toddrme2178@gmail.com
- Fix shebangs
* Mon Aug 28 2017 toddrme2178@gmail.com
- Update to 5.9
  * Added support for Qt v5.9.0 and v5.9.1.
  * Improved detection of the destruction of QObject-based instances by C++.
  * QFlags instances are now hashable.
  * pyrcc5 now supports v2 of the resource file format.
  * Added the interview.py, frozencolumn.py and storageview.py examples from
    Hans-Peter Jansen.
  * SIP v4.19.3 is required.
- Remove reproducible.patch
  Implemented upstream.
* Fri Jun  2 2017 jengelh@inai.de
- Trim redundant platform support mentions.
* Mon May 22 2017 bwiedemann@suse.com
- Add reproducible.patch to sort input files to make build fully reproducible
* Tue May 16 2017 toddrme2178@gmail.com
- Fix issues with requires.
* Fri Apr 21 2017 mpluskal@suse.com
- Move requirements for development package to correct place
* Sat Apr  8 2017 hpj@urpla.net
- Update to 5.8.2
  * lib/configure.py:
    Fixes for the OpenGL detection needed by the incompatible
    configuration changes in Qt v5.8.0.
  * qpy/QtCore/qpycore_chimera.cpp:
    When parsing a Python type map list and dict to QVariantList and
    QVariantMap.
  * lib/LICENSE.commercial, lib/LICENSE.commercial.short,
    lib/LICENSE.gpl, lib/LICENSE.gpl.short, lib/LICENSE.internal:
    Remove the license copies that are now part of rb-tools.
  * pyuic/uic/uiparser.py:
    Fixed the margins of the top layout in a tab by pyuic.
  * pyuic/uic/driver.py, pyuic/uic/exceptions.py,
    pyuic/uic/properties.py, pyuic/uic/pyuic.py:
    Improved the error handling of an unknown C++ class.
  * sphinx/qml.rst:
    Added explicit warnings about PyQt's ability to support QML to the
    docs.
  * PyQt5.msp:
    Added a comment about why opengl_types.sip is included twice.
  * PyQt5.msp:
    Only enable QOpenGLTextureBlitter if OpenGL is supported.
  * PyQt5.msp:
    Avoid a deadlock when using asynchronous image providers in QML.
- Update to 5.8.1
  * qpy/QtCore/qpycore_chimera.cpp:
    Special case a QVariant containing std::nullptr_t.
  * METADATA.in:
    Updated the Requires-Dist meta-data so it includes the values from
    the release file.
  * lib/configure.py:
    Disable desktop OpenGL if OpenGLES v3 or v3.1 is detected.
  * qpy/QtQml/qpyqml_register_type.cpp:
    Fixed the handling of properties in Qml because of changes to the
    internals in Qt v5.8.0.
  * PyQt5.msp:
    Fixed QLocale.toString() for Python v2.
  * PyQt5.msp:
    Anticipate that Qt v5.9.0 will be released before Qt v5.8.1 to avoid
    problems building PyQt v5.9 against Qt v5.8.1.
  * qpy/QtPrintSupport/qpyprintsupport_qlist.sip:
    The QtPrintSupport mapped types are only included if printers are
    supported.
  * sphinx/pyqt_qvariant.rst:
    Updated the docs regarding support for QVariant.
  * qpy/QtQml/qpyqmlobject.cpp:
    Fixed signals in QML registered types that are defined in a Python
    sub-class of the registered type.
* Wed Mar 29 2017 toddrme2178@gmail.com
- Fix singlespec macro usage.  BuildRequires are shared between
  python versions, only the requires should be specific to particular
  python versions.
* Fri Mar 24 2017 lbeltrame@kde.org
- Temporarily undo some of the single spec changes to allow building
  until a newer python-dbus is available
* Mon Mar  6 2017 toddrme2178@gmail.com
- Switch to single-spec version.
- Add doc-file-dependency to rpmlintrc to handle the example files.
* Wed Feb 15 2017 termim@gmail.com
- Update to 5.8
  * Added support for Qt v5.8.0.
  * Added __fspath__() to QFileInfo.
  * Added the --qml-debug option to configure.py. The --debug option
    no longer enables the QML debugging infrastructure.
  * Added the --link-full-dll option to configure.py.
- Removed patches:
  * disable_qml_debug.diff - fixed upstream
  * fix_qreal_check.diff - not needed acording the package developer
  * license.diff - fixed upstream
  * obsolete_window_flag.diff - fixed upstream
* Tue Jan  3 2017 termim@gmail.com
- Update to 5.7.1
  * added the QtWebEngine module
  * added QRegion.setRects()
  * added QtMac to the QtMacExtras module
  * added support for QChartView and QWebEngineView to pyuic5.
* Wed Nov 30 2016 hrvoje.senjan@gmail.com
- Add obsolete_window_flag.diff: remore declaration that was removed
  in Qt 5.8 (it was WinCE-only)
- Add license.diff: QLibrary::Licensee is deprecated in Qt 5.8, and
  produce empty string. We know we are always building opensource
  Qt.
* Tue Nov 15 2016 lbeltrame@kde.org
- Remove Source URL, the validator doesn't work too well with
  SourceForge
* Mon Nov 14 2016 hpj@urpla.net
- add patch to disable qml_debug: disable_qml_debug.diff.
  Without this, the message "QML debugging is enabled. Only use
  this in a safe environment."  appears on PyQt5 apps startup,
  and allows qmljsdebugger to  connect via network.
* Tue Nov  8 2016 hpj@urpla.net
- make utils dependent on exact version
* Tue Jul 26 2016 termim@gmail.com
- Update to 5.7
  * Added support for Qt v5.7.0.
  * Removed patch pyqt5-fix-dbus-config.diff as applyed upstream
* Mon Jul  4 2016 hpj@urpla.net
- Update to 5.6
  * Added full support for Qt v5.6.0.
  * Python v3.5 wheels are available for 64-bit Linux, 64-bit OS X
    and 32 and 64-bit Windows. (After this release Windows .exe
    installers will no longer be produced.)
  * Added the QtWebEngineCore module.
  * Added the missing qt_set_sequence_auto_mnemonic() to QtGui.
  * Added the missing MouseLock to QWebEnginePage.Feature.
  * Added the missing WA_DontShowOnScreen.
  * PEP 484 stub files are installed by default.
  * Added the --import-from command line argument to pyuic5.
  * Added the --no-stubs and --stubsdir options to configure.py.
  * Added the --qtconf-prefix option to configure.py.
- add PATCH-FIX-OPENSUSE pyqt5-fix-dbus-config.diff to fix build of
  dbus bindings
- supply %%{optflags} to the QMAKE machinery
- add libqt5-qtlocation-devel build dependency
* Sun Jun  5 2016 hrvoje.senjan@gmail.com
- Drop unused libqt5-qtquick1-devel (Build)Requires
* Mon Mar  7 2016 dvaleev@suse.com
- Don't buildrequire libqt5-qtwebengine-devel for POWER and s390x
* Mon Feb  1 2016 lbeltrame@kde.org
- BuildRequire libqt5-qtconnectivity-devel to gain support for
  QtBluetooth (bnc#964256)
* Fri Oct 30 2015 termim@gmail.com
- Update to 5.5.1
  * added support for Qt v5.5.1
  * added the --disable option to configure.py
  * implemented __matmul__ and __imatmul__ for QMatrix4x4 and
    QTransform.
* Fri Aug 14 2015 termim@gmail.com
- change required sip version to 4.16.9
* Mon Jul 20 2015 termim@gmail.com
- remove patch build-compare.diff as adapted in upstream
- Update to 5.5
  * Added full support for Qt v5.5.0.
  * Added the QtLocation module.
  * Added the QtNfc module.
  * Added Qt.NoOpaqueDetection amd Qt.NoFormatConversion to QtCore.
  * Added QMacToolBar and QMacToolBarItem to QtMacExtras.
  * Added QProxyStyle to QtWidgets.
- Update to 5.4.2
  * Added support for Qt v5.4.2.
  * Added QWIDGETSIZE_MAX to QtWidgets.
  * Added the --no-python-dbus command line option to configure.py.
- Update to 5.4.1
  * Added support for Qt v5.4.1.
  * Added the QMacCocoaViewContainer class.
  * All OpenGL examples use QOpenGLWidget and no longer require
    PyOpenGL.
  * Added initial implementations of _QOpenGLFunctions_2_1 and
    _QOpenGLFunctions_4_1_Core.
  * QEvent.None is now QEvent.None_.
  * Added missing QEvent.Type members that are now documented in Qt.
  * Added the --license-dir option to configure.py.
  * Installing into a virtual env should now work.
  * pyuic5 and pyrcc5 no longer include a timestamp in the
    generated code.
* Fri Jan 16 2015 hrvoje.senjan@gmail.com
- Enable QtWebEngineWidgets and QtWebChannel integration
- Update build-compare.diff
- Drop fdupes usage due to unpredictable symlinking
- Add rpmlintrc due to duplicates waste warnings: we rather have
  a few bytes more than to republish same binaries due to fdupes
* Tue Dec 30 2014 hrvoje.senjan@gmail.com
- Update to 5.4
  * Major functional release that adds full support for Qt v5.4.0.
  * Added the QtWebChannel module
  * Added the QtWebEngineWidgets module
  * Added the QtXml module.
- Drop add_dep.patch, merged upstream
- Bump python(3)-sip-devel (Build)Requires to 4.16.4
* Sat Oct 11 2014 hrvoje.senjan@gmail.com
- Update to 5.3.2
  * Added the Enginio module.
  * Added the QJsonDocument and QJsonValue classes.
  * QJsonObject is implemented as a Python dict.
  * QJsonArray is implemented as a Python list.
  * Added setUnifiedTitleAndToolBarOnMac() and
    unifiedTitleAndToolBarOnMac() to QWidget.
  * Added windowHandle() to QWidget.
- Drop usage of rversion, use version directly
- Disable disable-rpaths.diff, upstream removed RPATH usage in this
  release
* Wed Sep 10 2014 hrvoje.senjan@gmail.com
- Added add_dep.patch: make the buildsystem know that QtPrintSUpport
  module is needed for QtWebkitWidgets one, previously the build
  only succeeded due to QTBUG-39249
* Sun Jul  6 2014 hrvoje.senjan@gmail.com
- Update to 5.3.1
  * minor bug-fix release
* Wed Jun 25 2014 hrvoje.senjan@gmail.com
- Drop link-python.diff, it's unused
* Thu May 29 2014 hrvoje.senjan@gmail.com
- Update to 5.3
  * By default a Python slot is only invoked if the underlying C++
    instance still exists.
  * Added the no_receiver_check argument to connect().
  * Added support for Qt v5.3.0.
  * Added the QtQuickWidgets module.
  * Added the QtWebSockets module.
  * Added the --target_py_version, --sysroot and --no-tools option
    to configure.py.
  * Cross-compilation (specifically to iOS and Android) is now supported
- Drop qglobal.patch, included in this release
- Added libqt5-qtwebsockets-devel BuildRequires
- Bump required python(3)-sip-devel version to 4.16
* Fri May 16 2014 hrvoje.senjan@gmail.com
- Added qglobal.patch, to resolve build failure with Qt 5.3 API
* Sun May  4 2014 i@marguerite.su
- added missing qtmultimedia/qtserialport/qtxmlpatterns modules.
* Fri Mar 21 2014 hrvoje.senjan@gmail.com
- Update to 5.2.1
  * Full support for Qt v5.2.1.
  * Properties, signals and slots can now be defined in mixins
    (i.e. non-QObject classes).
  * Support for creating QSGGeometry.AttributeSet instances.
  * Fundamental values may now be given whenever a QJSValue
    is expected.
  * Building PyQt5 as static libraries now works.
  * Support for building without OpenGL.
- Bump sip BuildRequire to current requirements (4.15.5). Also,
  that is now minimal requires for devel subpackages
- Rebase disable-rpaths.diff for this release
- Disable fix_qreal_check.diff, for now the issue is fixed with
  Qt >= 5.2
- Drop checks for ancient releases
* Thu Feb  6 2014 hrvoje.senjan@gmail.com
- Added fix_qreal_check.diff, fixes build on arm
* Fri Jan 10 2014 lbeltrame@kde.org
- Use %%ghost with files generated by update-alternatives
* Fri Jan 10 2014 lbeltrame@kde.org
- New upstream release 5.2:
  - Full support for Qt5.2
  - Support added for the QtBluetooth, QtPositioning, QtMacExtras,
    QtWinExtras and QtX11Extras
- Fix SNAFU in preun scriptlet (missing spaces)
* Tue Dec 17 2013 hrvoje.senjan@gmail.com
- Move away from pkgconfig(...) BuildRequires and just use
  libqt5-$upstreammodulename-(devel|private-headers-devel)
* Mon Oct 21 2013 hrvoje.senjan@gmail.com
- Fix Requires for the devel packages
* Sun Oct 20 2013 lbeltrame@kde.org
- Use alternatives to prevent conflicts between Python 2 and Python 3
  tools
* Thu Oct 17 2013 toddrme2178@gmail.com
- New upstream release (5.1.1):
  * Bugfixes
- Rebase disable-rpaths.diff
* Sat Oct  5 2013 lbeltrame@kde.org
- New upstream release (5.1):
  * Full support for Qt 5.1
  * Support for QtSensors and QtSerialPort modules
  * Almost complete set of bindings for OpenGL 2.0 and OpenGL ES/2
- Bump required SIP version
* Wed Sep 11 2013 lbeltrame@kde.org
- New upstream release (5.0.1):
  * Added the QtQuick module including the ability to create
    Python Quick items from QML.
  * Added the QtQml module including the ability to create Python objects from
    QML.
  * Added the QtMultimediaWidgets module.
  * Completed the implementation of the QtMultimedia module including support
    for cameras and radios.
  * Added the remaining OpenGL classes to the QtGui module.
  * Added the revision keyword argument to pyqtProperty().
  * Added the revision and arguments keyword arguments to pyqtSignal().
  * Added the revision keyword argument to pyqtSlot().
  * Added the pyqt5qmlplugin plugin for qmlscene.
  * The DBus main loop module has been renamed to dbus.mainloop.pyqt5
    from dbus.mainloop.qt.
  * Added the --no-qml-plugin and --qml-plugindir options to configure.py.
  * Added many QtMultimedia, QML and QtQuick related examples.
  * Classes now support co-operative multi-inheritance. (This may
    introduce incompatibilities with PyQt v5.0.)
- Drop mainloop_rename.diff (merged upstream)
* Tue Aug  6 2013 lbeltrame@kde.org
- Add Patch3 to fix the dbus mainloop lib name (already upstream)
* Mon Aug  5 2013 lbeltrame@kde.org
- Initial package for PyQt5.
